@@ -1,7 +1,8 @@
 """test_generation"""
-
 import sys, time, unittest
 import urllib
+
+from nose.tools import eq_
 from routes import *
 
 class TestGeneration(unittest.TestCase):
@@ -19,7 +20,7 @@ class TestGeneration(unittest.TestCase):
         
             assert '/hi/index' == m.generate(fred='index')
             assert '/hi/show' == m.generate(fred='show')
-            assert '/hi/list+people' == m.generate(fred='list people')
+            assert '/hi/list%20people' == m.generate(fred='list people')
             assert None == m.generate()
     
     def test_dynamic_with_default(self):
@@ -29,7 +30,7 @@ class TestGeneration(unittest.TestCase):
         
             assert '/hi' == m.generate(action='index')
             assert '/hi/show' == m.generate(action='show')
-            assert '/hi/list+people' == m.generate(action='list people')
+            assert '/hi/list%20people' == m.generate(action='list people')
             assert '/hi' == m.generate()
     
     def test_dynamic_with_false_equivs(self):
@@ -269,6 +270,46 @@ class TestGeneration(unittest.TestCase):
         assert None == m.generate(controller='admin/comments', id=2)
         assert None == m.generate(controller='articles', action='find_by_date', year=2004)
 
+    def test_big_multiroute_with_nomin(self):
+        m = Mapper()
+        m.minimization = False
+        m.connect('', controller='articles', action='index')
+        m.connect('admin', controller='admin/general', action='index')
+
+        m.connect('admin/comments/article/:article_id/:action/:id', controller = 'admin/comments', action=None, id=None)
+        m.connect('admin/trackback/article/:article_id/:action/:id', controller='admin/trackback', action=None, id=None)
+        m.connect('admin/content/:action/:id', controller='admin/content')
+
+        m.connect('xml/:action/feed.xml', controller='xml')
+        m.connect('xml/articlerss/:id/feed.xml', controller='xml', action='articlerss')
+        m.connect('index.rdf', controller='xml', action='rss')
+
+        m.connect('articles', controller='articles', action='index')
+        m.connect('articles/page/:page', controller='articles', action='index', requirements = {'page':'\d+'})
+
+        m.connect('articles/:year/:month/:day/page/:page', controller='articles', action='find_by_date', month = None, day = None,
+                            requirements = {'year':'\d{4}', 'month':'\d{1,2}','day':'\d{1,2}'})
+        m.connect('articles/category/:id', controller='articles', action='category')
+        m.connect('pages/*name', controller='articles', action='view_page')
+        
+        
+        assert '/pages/the/idiot/has/spoken' == m.generate(controller='articles', action='view_page',
+                            name='the/idiot/has/spoken')
+        assert '/' == m.generate(controller='articles', action='index')
+        assert '/xml/articlerss/4/feed.xml' == m.generate(controller='xml', action='articlerss', id=4)
+        assert '/xml/rss/feed.xml' == m.generate(controller='xml', action='rss')
+        assert '/admin/comments/article/4/view/2' == m.generate(controller='admin/comments', action='view', article_id=4, id=2)
+        assert '/admin' == m.generate(controller='admin/general')
+        assert '/articles/2004/2/20/page/1' == m.generate(controller='articles', action='find_by_date', 
+                    year=2004, month=2, day=20, page=1)
+        assert None == m.generate(controller='articles', action='category')
+        assert '/articles/category/4' == m.generate(controller='articles', action='category', id=4)
+        assert '/xml/index/feed.xml' == m.generate(controller='xml')
+        assert '/xml/articlerss/feed.xml' == m.generate(controller='xml', action='articlerss')
+        
+        assert None == m.generate(controller='admin/comments', id=2)
+        assert None == m.generate(controller='articles', action='find_by_date', year=2004)
+
     def test_no_extras(self):
         m = Mapper()
         m.connect(':controller/:action/:id')
@@ -514,13 +555,13 @@ class TestGeneration(unittest.TestCase):
         m.create_regs(['messages'])
         options = dict(controller='messages')
         assert '/messages' == url_for('messages')
-        assert '/messages.xml' == url_for('messages', format='xml')
+        assert '/messages.xml' == url_for('formatted_messages', format='xml')
         assert '/messages/1' == url_for('message', id=1)
-        assert '/messages/1.xml' == url_for('message', id=1, format='xml')
+        assert '/messages/1.xml' == url_for('formatted_message', id=1, format='xml')
         assert '/messages/new' == url_for('new_message')
-        assert '/messages/1.xml' == url_for('message', id=1, format='xml')
+        assert '/messages/1.xml' == url_for('formatted_message', id=1, format='xml')
         assert '/messages/1/edit' == url_for('edit_message', id=1)
-        assert '/messages/1/edit.xml' == url_for('edit_message', id=1, format='xml')
+        assert '/messages/1/edit.xml' == url_for('formatted_edit_message', id=1, format='xml')
         self._assert_restful_routes(m, options)
     
     def test_resources_with_path_prefix(self):
@@ -560,7 +601,7 @@ class TestGeneration(unittest.TestCase):
         assert '/messages/new/preview' == m.generate(controller='messages', action='preview', method='post')
         assert '/messages/new/preview' == url_for('preview_new_message')
         assert '/messages/new/preview.xml' == m.generate(controller='messages', action='preview', method='post', format='xml')
-        assert '/messages/new/preview.xml' == url_for('preview_new_message', format='xml')
+        assert '/messages/new/preview.xml' == url_for('formatted_preview_new_message', format='xml')
     
     def test_resources_with_name_prefix(self):
         m = Mapper()
@@ -569,11 +610,11 @@ class TestGeneration(unittest.TestCase):
         options = dict(controller='messages')
         self._assert_restful_routes(m, options)
         assert '/messages/new/preview' == url_for('category_preview_new_message')
-        assert None == url_for('category_preview_new_message', method='get')
+        self.assertRaises(Exception, url_for, 'category_preview_new_message', method='get')
 
     def test_unicode(self):
         hoge = u'\u30c6\u30b9\u30c8' # the word test in Japanese
-        hoge_enc = urllib.quote_plus(hoge.encode('utf-8'))
+        hoge_enc = urllib.quote(hoge.encode('utf-8'))
         m = Mapper()
         m.connect(':hoge')
         self.assertEqual("/%s" % hoge_enc, m.generate(hoge=hoge))
@@ -581,9 +622,10 @@ class TestGeneration(unittest.TestCase):
 
     def test_unicode_static(self):
         hoge = u'\u30c6\u30b9\u30c8' # the word test in Japanese
-        hoge_enc = urllib.quote_plus(hoge.encode('utf-8'))
+        hoge_enc = urllib.quote(hoge.encode('utf-8'))
         m = Mapper()
         m.connect('google-jp', 'http://www.google.co.jp/search', _static=True)
+        m.create_regs(['messages'])
         self.assertEqual("http://www.google.co.jp/search?q=" + hoge_enc,
                          url_for('google-jp', q=hoge))
         self.assert_(isinstance(url_for('google-jp', q=hoge), str))
@@ -598,7 +640,6 @@ class TestGeneration(unittest.TestCase):
         assert '/2007/test.xml,ja' == m.generate(year=2007, slug='test', format='xml', locale='ja')
         assert None == m.generate(year=2007, format='html')
 
-
 if __name__ == '__main__':
     unittest.main()
 else:
